package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;

import java.util.List;

import com.yunzhi.inte.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.CooperationPerson;
import com.yunzhi.inte.service.CooperationPersonService;

/**
 * 保障机构人员;(cooperation_person)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-10-24
 */
@Api(tags = "保障机构人员对象功能接口")
@RestController
@RequestMapping("/")
public class CooperationPersonController extends BaseController {

    @Autowired
    private CooperationPersonService cooperationPersonService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/cooperationPerson/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(cooperationPersonService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/cooperationPerson")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                             @ApiParam("机构ID") @RequestParam(value = "orgId", required = false) Integer orgId,
                             @ApiParam("人员名称") @RequestParam(value = "name", required = false) String name) throws Exception {

        IPage<CooperationPerson> pg = new Page<>(pageNum, pageSize);
        IPage<CooperationPerson> result = cooperationPersonService.getPageBy(pg, orgId, name);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param cooperationPerson 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/cooperationPerson")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody CooperationPerson cooperationPerson) throws Exception {
        cooperationPersonService.save(cooperationPerson);
        return ResponseBean.success(cooperationPerson);
    }

    /**
     * 更新数据
     *
     * @param cooperationPerson 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/cooperationPerson/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody CooperationPerson cooperationPerson,
                             @ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        cooperationPerson.setId(id);
        cooperationPersonService.updateById(cooperationPerson);
        return ResponseBean.success(cooperationPerson);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/cooperationPerson/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id) {
        cooperationPersonService.removeById(id);
        return ResponseBean.success("success");
    }
}