package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;

import java.util.List;

import com.yunzhi.inte.common.StringUtils;
import com.yunzhi.inte.entity.UnitsFiles;
import com.yunzhi.inte.mapper.UnitsFilesMapper;
import com.yunzhi.inte.service.UnitsFilesService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.CooperationUnits;
import com.yunzhi.inte.service.CooperationUnitsService;

/**
 * 保障机构;(cooperation_units)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-10-24
 */
@Api(tags = "保障机构对象功能接口")
@RestController
@RequestMapping("/")
public class CooperationUnitsController extends BaseController {

    @Autowired
    private CooperationUnitsService cooperationUnitsService;

    @Autowired
    private UnitsFilesService unitsFilesService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/cooperationUnits/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        CooperationUnits cooperationUnits = cooperationUnitsService.getById(id);
        List<UnitsFiles> fileList = unitsFilesService.getByOrg(id);
        cooperationUnits.setFileList(fileList);

        return ResponseBean.success(cooperationUnits);
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/cooperationUnits")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                             @ApiParam("名称") @RequestParam(value = "name", required = false) String name,
                             @ApiParam("机构类别") @RequestParam(value = "orgType", required = false) String orgType) throws Exception {

        IPage<CooperationUnits> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<CooperationUnits> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(name), "name", name);
        queryWrapper.like(!StringUtils.isEmpty(orgType), "org_type", orgType);
        queryWrapper.orderByDesc("id");
        IPage<CooperationUnits> result = cooperationUnitsService.page(pg, queryWrapper);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param cooperationUnits 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/cooperationUnits")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody CooperationUnits cooperationUnits) throws Exception {
        cooperationUnitsService.mergeData(cooperationUnits);
        return ResponseBean.success(cooperationUnits);
    }

    /**
     * 更新数据
     *
     * @param cooperationUnits 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/cooperationUnits/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody CooperationUnits cooperationUnits,
                             @ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        cooperationUnits.setId(id);
        cooperationUnitsService.updateById(cooperationUnits);
        return ResponseBean.success(cooperationUnits);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/cooperationUnits/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id) {
        cooperationUnitsService.removeById(id);
        return ResponseBean.success("success");
    }
}