package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.Constants;
import com.yunzhi.inte.common.ResponseBean;

import java.util.List;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.Evaluate;
import com.yunzhi.inte.service.EvaluateService;

/**
 * 评价表;(evaluate)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-10-13
 */
@Api(tags = "评价表对象功能接口")
@RestController
@RequestMapping("/")
public class EvaluateController extends BaseController {

    @Autowired
    private EvaluateService evaluateService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/evaluate/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(evaluateService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/evaluate")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) throws Exception {

        IPage<Evaluate> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<Evaluate> queryWrapper = new QueryWrapper<>();
        queryWrapper.gt("status", Constants.STATUS_DELETE);
        queryWrapper.orderByDesc("create_date");
        IPage<Evaluate> result = evaluateService.page(pg, queryWrapper);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param evaluate 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/evaluate")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody Evaluate evaluate) throws Exception {
        evaluateService.save(evaluate);
        return ResponseBean.success(evaluate);
    }

    /**
     * 更新数据
     *
     * @param evaluate 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/evaluate/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody Evaluate evaluate,
                             @ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        evaluateService.updateById(evaluate);
        return ResponseBean.success(evaluate);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/evaluate/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id) {
        evaluateService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}