package com.yunzhi.inte.controller;

import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.yunzhi.inte.common.*;
import com.yunzhi.inte.entity.Users;
import com.yunzhi.inte.vo.ChangePassword;
import com.yunzhi.inte.vo.LoginParm;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;


@Api(tags ="登录")
@RestController
@RequestMapping("/")
public class LoginController extends BaseController {


    @PostMapping("/login")
    @ApiOperation(value="后台登录", notes = "后台登录", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean login(@ApiParam("登录参数") @RequestBody LoginParm loginParm) throws Exception {

        if (StringUtils.isEmpty(loginParm.getUserName()) || StringUtils.isEmpty(loginParm.getPassword())) {
            return ResponseBean.error("登录用户或者密码不能为空");
        }

        Users sysUser = usersService.login(loginParm);
        if (sysUser.getStatus() != Constants.STATUS_NORMAL) {
            return ResponseBean.error("当前账号异常");
        }

        StpUtil.login(sysUser.getId(), "admin");
        String tokenValue = StpUtil.getTokenValue();

        Map<String, Object> result = new HashMap<>();
        result.put("user", sysUser);
        result.put("token", tokenValue);

        return ResponseBean.success(result);
    }

    @PostMapping("/logout")
    @ApiOperation(value="登出", notes = "登出", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean logout() throws Exception {
        StpUtil.logout();
        return ResponseBean.success("success");
    }

    @PutMapping("/change-password")
    @ApiOperation(value="修改密码", notes = "修改密码", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean changePassword(@ApiParam("修改密码参数") @RequestBody ChangePassword param) throws Exception {
        if (StringUtils.isEmpty(param.getOriginPassword()) || StringUtils.isEmpty(param.getNewPassword())) {
            return ResponseBean.error("原始密码或新密码不能为空", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        Users currentUser = currentUser();
        String userId = currentUser.getId().toString();

        if (!checkPassword(param.getOriginPassword(), currentUser.getPassword(), userId)) {
            return ResponseBean.error("原始密码不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        currentUser.setPassword(EncryptUtils.md5(param.getNewPassword(), userId));
        usersService.updateById(currentUser);

        return ResponseBean.success("密码修改成功");
    }

    private boolean checkPassword(String src, String targ, String salt) {
        return EncryptUtils.md5(src, salt).equals(targ);
    }
}
