package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;

import java.time.LocalDateTime;
import java.util.List;

import com.yunzhi.inte.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.NoticeMessage;
import com.yunzhi.inte.service.NoticeMessageService;

/**
 * 消息表;(notice_message)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-10-13
 */
@Api(tags = "消息表对象功能接口")
@RestController
@RequestMapping("/")
public class NoticeMessageController extends BaseController {

    @Autowired
    private NoticeMessageService noticeMessageService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/noticeMessage/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(noticeMessageService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/noticeMessage")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                             @ApiParam("起始时间") @RequestParam(value = "startDate", required = false) String startDate,
                             @ApiParam("结束时间") @RequestParam(value = "endDate", required = false) String endDate,
                             @ApiParam("消息内容") @RequestParam(value = "message", required = false) String message) throws Exception {

        IPage<NoticeMessage> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<NoticeMessage> queryWrapper = new QueryWrapper<>();

        if (!StringUtils.isEmpty(startDate) && !StringUtils.isEmpty(endDate)) {
            queryWrapper.ge("create_date", startDate);
            queryWrapper.le("create_date", endDate);
        }
        queryWrapper.like(!StringUtils.isEmpty(message), "message", message);

        queryWrapper.orderByAsc("is_readed");
        queryWrapper.orderByDesc("create_date");
        IPage<NoticeMessage> result = noticeMessageService.page(pg, queryWrapper);

        return ResponseBean.success(result);
    }

//    /**
//     * 新增数据
//     *
//     * @param noticeMessage 实例对象
//     * @return 实例对象
//     */
//    @ApiOperation("新增数据")
//    @PostMapping("/noticeMessage")
//    public ResponseBean add(@ApiParam("对象实体") @RequestBody NoticeMessage noticeMessage) throws Exception {
//        noticeMessageService.save(noticeMessage);
//        return ResponseBean.success(noticeMessage);
//    }

    /**
     * 更新数据
     *
     * @param id 对象ID
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/noticeMessage/{id}/readed")
    public ResponseBean edit(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        NoticeMessage noticeMessage = noticeMessageService.getById(id);
        if (null == noticeMessage) {
            return ResponseBean.error("未找到消息内容");
        }

        noticeMessage.setIsReaded(true);
        noticeMessageService.updateById(noticeMessage);
        return ResponseBean.success(noticeMessage);
    }

//    /**
//     * 通过主键删除数据
//     *
//     * @param id 主键
//     * @return 是否成功
//     */
//    @ApiOperation("通过主键删除数据")
//    @DeleteMapping("/noticeMessage/{id}")
//    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
//        noticeMessageService.removeLogicById(id);
//        return ResponseBean.success("success");
//    }
}