package com.yunzhi.inte.controller;

import com.alibaba.excel.write.handler.WriteHandler;
import com.alibaba.excel.write.merge.AbstractMergeStrategy;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.*;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

import com.yunzhi.inte.common.excel.CustomMergeStrategy;
import com.yunzhi.inte.entity.Dishes;
import com.yunzhi.inte.entity.PackageDetail;
import com.yunzhi.inte.entity.Store;
import com.yunzhi.inte.vo.PackageExport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.Package;
import com.yunzhi.inte.service.PackageService;

import javax.servlet.http.HttpServletResponse;

/**
 * 套餐;(package)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-9-17
 */
@Api(tags = "套餐对象功能接口")
@RestController
@RequestMapping("/")
public class PackageController extends BaseController {

    @Autowired
    private PackageService packageService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/package/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(packageService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/package")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                             @ApiParam("套餐名称") @RequestParam(value ="name", required = false) String name) throws Exception {

        IPage<Package> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<Package> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(name), "name", name);
        queryWrapper.eq("status", Constants.STATUS_NORMAL);
        queryWrapper.orderByDesc("id");
        IPage<Package> result = packageService.page(pg, queryWrapper);

        return ResponseBean.success(result);
    }


    /**
     * 导出套餐
     *
     * @return 查询结果
     */
    @ApiOperation("导出套餐")
    @GetMapping("/package/export")
    public void export(HttpServletResponse response) throws Exception {
        List<PackageDetail> result = packageService.exportAll();
        List<PackageExport> exportList = new ArrayList<>();
        if (null != result && result.size() > 0) {
            int no = 0;
            String lastName = "";
            for (int i = 0; i < result.size(); i += 1) {
                PackageDetail detail = result.get(i);
                if (!lastName.equals(detail.getPackageName())) {
                    no += 1;
                }
                lastName = detail.getPackageName();

                PackageExport item = new PackageExport();
                item.setNo(no);
                item.setPackageName(detail.getPackageName());
                item.setDishName(String.format("【%s】%s", 1 == detail.getDishKind() ? "主食": "菜肴", detail.getDishName()));
                exportList.add(item);
            }
        }

        // 单元格合并策略
        List<String> mergeNo = exportList.stream().map(x -> x.getNo().toString()).collect(Collectors.toList());
        List<String> mergeName = exportList.stream().map(PackageExport::getPackageName).collect(Collectors.toList());
        CustomMergeStrategy mergeStrategy1 = new CustomMergeStrategy(mergeNo, 0);
        CustomMergeStrategy mergeStrategy2 = new CustomMergeStrategy(mergeName, 1);
        List<WriteHandler> mergeStrategyList = new ArrayList<WriteHandler>() {{
            add(mergeStrategy1);
            add(mergeStrategy2);
        }};

        ExcelUtils.flush2(response, PackageExport.class, exportList, "套餐列表", mergeStrategyList);
    }

    /**
     * 新增数据
     *
     * @param pkg 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/package")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody Package pkg) throws Exception {
        Package origin = packageService.getExistBy("name", pkg.getName(), false, true);
        if (null != origin) {
            return ResponseBean.error("当前名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        packageService.save(pkg);
        return ResponseBean.success(pkg);
    }

    /**
     * 更新数据
     *
     * @param pkg 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/package/{id}")
    public ResponseBean edit(@ApiParam("对象ID") @PathVariable Integer id,
                             @ApiParam("对象实体") @RequestBody Package pkg) throws Exception {
        Package origin = packageService.getExistBy("name", pkg.getName(), false, true);
        if (null != origin && !id.equals(origin.getId())) {
            return ResponseBean.error("当前名称重复", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        packageService.updateById(pkg);
        return ResponseBean.success(pkg);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/package/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        packageService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}