package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.Constants;
import com.yunzhi.inte.common.ResponseBean;

import java.time.LocalDateTime;
import java.util.List;

import com.yunzhi.inte.common.StringUtils;
import com.yunzhi.inte.entity.PostsFiles;
import com.yunzhi.inte.service.PostsFilesService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.Posts;
import com.yunzhi.inte.service.PostsService;

/**
 * 信息发布表;(posts)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-10-16
 */
@Api(tags = "信息发布表对象功能接口")
@RestController
@RequestMapping("/")
public class PostsController extends BaseController {

    @Autowired
    private PostsService postsService;

    @Autowired
    private PostsFilesService postsFilesService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/posts/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        Posts posts = postsService.getById(id);
        if (null == posts) {
            return ResponseBean.error("未找到数据");
        }

        List<PostsFiles> filesList = postsFilesService.getFilesByPosts(id);
        posts.setFilesList(filesList);

        return ResponseBean.success(posts);
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/posts")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                             @ApiParam("标题") @RequestParam(value = "title", required = false) String title,
                             @ApiParam("类型") @RequestParam(value = "type", required = false) String type,
                             @ApiParam("状态") @RequestParam(value = "status", required = false) Integer status) throws Exception {

        IPage<Posts> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<Posts> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(title), "title", title);
        queryWrapper.eq(!StringUtils.isEmpty(type), "type", type);
        queryWrapper.eq(null != status, "status", status);
        queryWrapper.gt("status", Constants.STATUS_DELETE);

        queryWrapper.orderByDesc("create_date");
        IPage<Posts> result = postsService.page(pg, queryWrapper);

        return ResponseBean.success(result);
    }

    /**
     * 新增,修改数据
     *
     * @param posts 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增,修改数据")
    @PostMapping("/posts")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody Posts posts) throws Exception {

        if (posts.getStatus() == null) {
            posts.setStatus(Constants.STATUS_NORMAL);
        }

        postsService.mergeData(posts);
        return ResponseBean.success(posts);
    }

    /**
     * 更新数据
     *
     * @param posts 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/posts/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody Posts posts,
                             @ApiParam("对象ID") @PathVariable Integer id) throws Exception {

        posts.setId(id);

        postsService.updateById(posts);
        return ResponseBean.success(posts);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/posts/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id) {
        postsService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}