package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;

import java.util.List;

import com.yunzhi.inte.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.PostsFiles;
import com.yunzhi.inte.service.PostsFilesService;

/**
 * 关联文件;(posts_files)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-10-13
 */
@Api(tags = "关联文件对象功能接口")
@RestController
@RequestMapping("/")
public class PostsFilesController extends BaseController {

    @Autowired
    private PostsFilesService postsFilesService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/postsFiles/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(postsFilesService.getById(id));
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/postsFiles")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                             @ApiParam("文件名称") @RequestParam(value = "fileName", required = false) String fileName,
                             @ApiParam("文件类型") @RequestParam(value = "fileType", required = false) String fileType) throws Exception {

        IPage<PostsFiles> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<PostsFiles> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(fileName), "file_name", fileName);
        queryWrapper.eq(!StringUtils.isEmpty(fileType), "file_type", fileType);
        queryWrapper.orderByDesc("id");
        IPage<PostsFiles> result = postsFilesService.page(pg, queryWrapper);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param postsFiles 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/postsFiles")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody PostsFiles postsFiles) throws Exception {
        postsFilesService.save(postsFiles);
        return ResponseBean.success(postsFiles);
    }

    /**
     * 更新数据
     *
     * @param postsFiles 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/postsFiles/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody PostsFiles postsFiles,
                             @ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        postsFilesService.updateById(postsFiles);
        return ResponseBean.success(postsFiles);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/postsFiles/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id) {
        postsFilesService.removeById(id);
        return ResponseBean.success("success");
    }
}