package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.Constants;
import com.yunzhi.inte.common.ResponseBean;

import java.time.LocalDateTime;
import java.util.List;

import com.yunzhi.inte.common.StringUtils;
import com.yunzhi.inte.entity.PurchaseItems;
import com.yunzhi.inte.service.PurchaseItemsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.Purchase;
import com.yunzhi.inte.service.PurchaseService;

/**
 * 采购表;(purchase)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-10-14
 */
@Api(tags = "采购表对象功能接口")
@RestController
@RequestMapping("/")
public class PurchaseController extends BaseController {

    @Autowired
    private PurchaseService purchaseService;

    @Autowired
    private PurchaseItemsService purchaseItemsService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/purchase/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        Purchase purchase = purchaseService.getById(id);
        if (null != purchase) {
            List<PurchaseItems> itemsList = purchaseItemsService.getByPurchase(id);
            purchase.setItemsList(itemsList);
        }

        return ResponseBean.success(purchase);
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/purchase")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                             @ApiParam("计划名称") @RequestParam(value = "title", required = false) String title,
                             @ApiParam("计划时间") @RequestParam(value = "planDate", required = false) String planDate,
                             @ApiParam("是否完成") @RequestParam(value = "isCompleted", required = false) Boolean isCompleted) throws Exception {

        IPage<Purchase> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<Purchase> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(title), "title", title);
        queryWrapper.like(!StringUtils.isEmpty(planDate), "plan_date", planDate);
        queryWrapper.eq(null != isCompleted, "is_completed", null != isCompleted && isCompleted ? 1 : 0);
        queryWrapper.gt("status", Constants.STATUS_DELETE);
        queryWrapper.orderByDesc("create_date");
        IPage<Purchase> result = purchaseService.page(pg, queryWrapper);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param purchase 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/purchase")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody Purchase purchase) throws Exception {

        if (purchase.getId() != null) {
            // 如果是采购完成
            Purchase origin = purchaseService.getById(purchase.getId());
            if ((null == origin.getIsCompleted() || !origin.getIsCompleted())
                    && null != purchase.getIsCompleted() && purchase.getIsCompleted()) {
                purchase.setCompletedDate(LocalDateTime.now());
            }
        }

        purchaseService.mergeData(purchase);
        return ResponseBean.success(purchase);
    }

    /**
     * 采购入库
     *
     * @param id 实例 ID
     * @return 实例对象
     */
    @ApiOperation("采购入库")
    @PutMapping("/purchase/{id}/in-store")
    public ResponseBean inStore(@ApiParam("对象ID") @PathVariable Integer id ) throws Exception {
        purchaseService.inStore(id, currentUser());
        return ResponseBean.success("success");
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/purchase/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id) {
        Purchase purchase = purchaseService.getById(id);

        if (null == purchase) {
            return ResponseBean.success("success");
        }
        if (null != purchase.getIsInStore() && purchase.getIsInStore()) {
            return ResponseBean.error("采购项目已入库, 禁止删除");
        }

        purchaseService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}