package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.PurchaseItems;
import com.yunzhi.inte.service.PurchaseItemsService;

 /**
 * 采购内容;(purchase_items)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-10-14
 */
@Api(tags = "采购内容对象功能接口")
@RestController
@RequestMapping("/")
public class PurchaseItemsController extends BaseController {
    
    @Autowired
    private PurchaseItemsService purchaseItemsService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/purchaseItems/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(purchaseItemsService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/purchaseItems")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<PurchaseItems> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<PurchaseItems> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<PurchaseItems> result = purchaseItemsService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param purchaseItems 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/purchaseItems")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody PurchaseItems purchaseItems) throws Exception {
        purchaseItemsService.save(purchaseItems);
        return ResponseBean.success(purchaseItems);
    }
    
    /** 
     * 更新数据
     *
     * @param purchaseItems 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/purchaseItems/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody PurchaseItems purchaseItems,
                            @ApiParam("对象ID") @PathVariable Integer id ) throws Exception {
        purchaseItemsService.updateById(purchaseItems);
        return ResponseBean.success(purchaseItems);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/purchaseItems/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        purchaseItemsService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}