package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.Resources;
import com.yunzhi.inte.service.ResourcesService;

 /**
 * 资源;(resources)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-10-12
 */
@Api(tags = "资源对象功能接口")
@RestController
@RequestMapping("/")
public class ResourcesController extends BaseController {
    
    @Autowired
    private ResourcesService resourcesService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/resources/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(resourcesService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param type 资源类型
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/resources")
    public ResponseBean list(@ApiParam("资源类型") @RequestParam(value = "type") String type,
                             @ApiParam("角色ID") @RequestParam(value = "roleId", required = false) Integer roleId) throws Exception {

        List<Resources> result = resourcesService.listBy(type, roleId);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param resources 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/resources")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody Resources resources) throws Exception {
        resourcesService.save(resources);
        return ResponseBean.success(resources);
    }
    
    /** 
     * 更新数据
     *
     * @param resources 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/resources/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody Resources resources,
                            @ApiParam("对象ID") @PathVariable Integer id ) throws Exception {
        resourcesService.updateById(resources);
        return ResponseBean.success(resources);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/resources/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        resourcesService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}