package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;

import java.util.HashMap;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.RoleResources;
import com.yunzhi.inte.service.RoleResourcesService;

 /**
 * 角色资源;(role_resources)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-10-12
 */
@Api(tags = "角色资源对象功能接口")
@RestController
@RequestMapping("/")
public class RoleResourcesController extends BaseController {
    
    @Autowired
    private RoleResourcesService roleResourcesService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/roleResources/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(roleResourcesService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/roleResources")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<RoleResources> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<RoleResources> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<RoleResources> result = roleResourcesService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param roleId 角色ID
     * @param roleResourcesList 授权列表
     * @return 实例对象
     */
    @ApiOperation("新增数据, 包含编辑")
    @PostMapping("/role/{roleId}/Resources")
    public ResponseBean add(@ApiParam("角色ID") @PathVariable Integer roleId,
                            @ApiParam("授权列表") @RequestBody List<RoleResources> roleResourcesList) throws Exception {
        if (null == roleResourcesList) {
            return ResponseBean.error("未找到授权对象");
        }

        roleResourcesService.mergeData(roleId, roleResourcesList);
        return ResponseBean.success(roleResourcesList);
    }
    
    /** 
     * 更新数据
     *
     * @param roleResources 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/roleResources/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody RoleResources roleResources,
                            @ApiParam("对象ID") @PathVariable Integer id ) throws Exception {
        roleResourcesService.updateById(roleResources);
        return ResponseBean.success(roleResources);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/roleResources/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        roleResourcesService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}