package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;

import java.util.HashMap;
import java.util.List;

import com.yunzhi.inte.common.StringUtils;
import com.yunzhi.inte.service.UserRolesService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.Roles;
import com.yunzhi.inte.service.RolesService;

/**
 * 角色;(roles)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-10-12
 */
@Api(tags = "角色对象功能接口")
@RestController
@RequestMapping("/")
public class RolesController extends BaseController {

    @Autowired
    private RolesService rolesService;

    @Autowired
    private UserRolesService userRolesService;

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/roles/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(rolesService.getById(id));
    }

    /**
     * 分页查询
     *
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/roles")
    public ResponseBean list() throws Exception {

        QueryWrapper<Roles> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByDesc("name");
        List<Roles> result = rolesService.list(queryWrapper);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param roles 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/roles")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody Roles roles) throws Exception {

        if (StringUtils.isEmpty(roles.getName())) {
            return ResponseBean.error("角色名称不能为空");
        }

        int i = rolesService.countBy("name", roles.getName(), false);
        if (i > 0) {
            return ResponseBean.error("角色名称已存在");
        }

        rolesService.save(roles);
        return ResponseBean.success(roles);
    }

    /**
     * 更新数据
     *
     * @param roles 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/roles/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody Roles roles,
                             @ApiParam("对象ID") @PathVariable Integer id) throws Exception {

        if (StringUtils.isEmpty(roles.getName())) {
            return ResponseBean.error("角色名称不能为空");
        }

        Roles exists = rolesService.getByButNot("name", roles.getName(), "id", id, false);
        if (null != exists) {
            return ResponseBean.error("角色名称已存在");
        }

        roles.setId(id);
        rolesService.updateById(roles);
        return ResponseBean.success(roles);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/roles/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id) {
        rolesService.removeById(id);
        userRolesService.removeByMap(new HashMap<String, Object>() {{
            put("role_id", id);
        }});
        return ResponseBean.success("success");
    }
}