package com.yunzhi.inte.controller;

import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.DateUtils;
import com.yunzhi.inte.common.ResponseBean;
import com.yunzhi.inte.service.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.time.Duration;
import java.time.LocalDateTime;
import java.time.temporal.ChronoUnit;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Api(tags = "统计功能接口")
@RestController
@RequestMapping("/statis")
public class StatisController extends BaseController {

    @Autowired
    GuaranteeTaskService guaranteeTaskService;

    @Autowired
    StoreService storeService;

    @Autowired
    UsersService usersService;

    @Autowired
    PurchaseService purchaseService;

    @Autowired
    EvaluateService evaluateService;

    @ApiOperation("汇总统计")
    @GetMapping("/summary")
    public ResponseBean getSummary() {

        // 任务总数
        Integer taskCount = guaranteeTaskService.total();
        // 接待军人总数
        Integer personNum = guaranteeTaskService.sumPerson();
        // 总体评价
        String evaValue = evaluateService.getTop1();
        // 设备数量
        Integer deviceNum = storeService.countDevice();

        return ResponseBean.success(new HashMap<String, Object>(){{
            put("taskCount", taskCount);
            put("personNum", personNum);
            put("evaValue", evaValue);
            put("deviceNum", deviceNum);
        }});
    }


    @ApiOperation("任务汇总")
    @GetMapping("/taskInfo")
    public ResponseBean getTaskInfo(@ApiParam("起始日期") @RequestParam(value ="startDate") String startDate,
                                    @ApiParam("起始日期") @RequestParam(value ="endDate") String endDate,
                                    @ApiParam("计量单位, 1 按天，2按月") @RequestParam(value ="unit", defaultValue = "1") String unit) {

        LocalDateTime dt1 = DateUtils.day2LocalDateime(startDate);
        LocalDateTime dt2 = DateUtils.day2LocalDateime(endDate);

        List<Map<String, Object>> result;
        if ("1".equals(unit)) {
            Long days = ChronoUnit.DAYS.between(dt1, dt2) + 1;
            result = guaranteeTaskService.countByDays(startDate, endDate, days);
        } else {
            long months = ChronoUnit.MONTHS.between(dt1, dt2) + 1;
            result = guaranteeTaskService.countByMonths(startDate, endDate, months);
        }

        return ResponseBean.success(result);
    }

    @ApiOperation("设备分类统计")
    @GetMapping("/deviceType")
    public ResponseBean getDeviceType() {

        List<Map<String, Integer>> result = storeService.countByDeviceType();
        return ResponseBean.success(result);
    }

    @ApiOperation("物资分类统计")
    @GetMapping("/storeType")
    public ResponseBean getStoreType(@ApiParam("起始日期") @RequestParam(value ="startDate") String startDate,
                                     @ApiParam("起始日期") @RequestParam(value ="endDate") String endDate) {

        List<Map<String, Integer>> result = storeService.countDeviceTypeOut(startDate, endDate);
        return ResponseBean.success(result);
    }

    @ApiOperation("人员学历统计")
    @GetMapping("/userEdu")
    public ResponseBean getUserEdu() {

        List<Map<String, Integer>> result = usersService.countEdu();
        return ResponseBean.success(result);
    }

    @ApiOperation("人员年龄统计")
    @GetMapping("/userAge")
    public ResponseBean getUserAge() {

        List<Map<String, Integer>> result = usersService.countAge();
        return ResponseBean.success(result);
    }

    @ApiOperation("成本分析")
    @GetMapping("/store-cost")
    public ResponseBean getStoreCost(@ApiParam("起始日期") @RequestParam(value ="startDate") String startDate,
                                     @ApiParam("起始日期") @RequestParam(value ="endDate") String endDate,
                                     @ApiParam("计量单位, 1 按天，2按月") @RequestParam(value ="unit", defaultValue = "1") String unit) {

        LocalDateTime dt1 = DateUtils.day2LocalDateime(startDate);
        LocalDateTime dt2 = DateUtils.day2LocalDateime(endDate);

        List<Map<String, Object>> res1, res2;
        if ("1".equals(unit)) {
            Long days = ChronoUnit.DAYS.between(dt1, dt2) + 1;
            // 采购成本
            res1 = purchaseService.getCostByDays(startDate, endDate, days);
            // 用料成本
            res2 = guaranteeTaskService.getCostByDays(startDate, endDate, days);
        } else {
            long months = ChronoUnit.MONTHS.between(dt1, dt2) + 1;
            res1 = purchaseService.getCostByMonths(startDate, endDate, months);
            res2 = guaranteeTaskService.getCostByMonths(startDate, endDate, months);
        }

        Map<String, Object> result = new HashMap<String, Object>(){{
            put("purchase", res1);
            put("taskCosts", res2);
        }};

        return ResponseBean.success(result);
    }

}
