package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.SupportCapability;
import com.yunzhi.inte.service.SupportCapabilityService;

 /**
 * 保障能力;(support_capability)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-10-24
 */
@Api(tags = "保障能力对象功能接口")
@RestController
@RequestMapping("/")
public class SupportCapabilityController extends BaseController {
    
    @Autowired
    private SupportCapabilityService supportCapabilityService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/supportCapability/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(supportCapabilityService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/supportCapability")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<SupportCapability> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<SupportCapability> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<SupportCapability> result = supportCapabilityService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param supportCapability 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/supportCapability")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody SupportCapability supportCapability) throws Exception {
        supportCapabilityService.save(supportCapability);
        return ResponseBean.success(supportCapability);
    }
    
    /** 
     * 更新数据
     *
     * @param supportCapability 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/supportCapability/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody SupportCapability supportCapability,
                            @ApiParam("对象ID") @PathVariable Integer id ) throws Exception {

        supportCapability.setId(id);

        SupportCapability origin = supportCapabilityService.getById(id);
        if (null == origin) {
            supportCapabilityService.save(supportCapability);
        } else {
            supportCapabilityService.updateById(supportCapability);
        }

        return ResponseBean.success(supportCapability);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/supportCapability/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        supportCapabilityService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}