package com.yunzhi.inte.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.ResponseBean;
import java.util.List;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.UnitsFiles;
import com.yunzhi.inte.service.UnitsFilesService;

 /**
 * 机构文件;(units_files)表控制层
 * @author : http://njyunzhi.com
 * @date : 2022-10-26
 */
@Api(tags = "机构文件对象功能接口")
@RestController
@RequestMapping("/")
public class UnitsFilesController extends BaseController {
    
    @Autowired
    private UnitsFilesService unitsFilesService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param id 主键
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/unitsFiles/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        return ResponseBean.success(unitsFilesService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/unitsFiles")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception {
        
        IPage<UnitsFiles> pg = new Page<>(pageNum, pageSize);
        // QueryWrapper<UnitsFiles> queryWrapper = new QueryWrapper<>();
        // queryWrapper.orderByDesc("create_date");
        IPage<UnitsFiles> result = unitsFilesService.page(pg);
        
        return ResponseBean.success(result);
    }
    
    /** 
     * 新增数据
     *
     * @param unitsFiles 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/unitsFiles")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody UnitsFiles unitsFiles) throws Exception {
        unitsFilesService.save(unitsFiles);
        return ResponseBean.success(unitsFiles);
    }
    
    /** 
     * 更新数据
     *
     * @param unitsFiles 实例对象
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/unitsFiles/{id}")
    public ResponseBean edit(@ApiParam("对象实体") @RequestBody UnitsFiles unitsFiles,
                            @ApiParam("对象ID") @PathVariable Integer id ) throws Exception {
        unitsFilesService.updateById(unitsFiles);
        return ResponseBean.success(unitsFiles);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/unitsFiles/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id){
        unitsFilesService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}