package com.yunzhi.inte.controller;

import cn.dev33.satoken.stp.StpUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.inte.common.BaseController;
import com.yunzhi.inte.common.Constants;
import com.yunzhi.inte.common.ResponseBean;

import java.util.List;

import com.yunzhi.inte.common.StringUtils;
import com.yunzhi.inte.entity.Resources;
import com.yunzhi.inte.entity.Roles;
import com.yunzhi.inte.service.ResourcesService;
import com.yunzhi.inte.service.RolesService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.inte.entity.Users;
import com.yunzhi.inte.service.UsersService;

/**
 * 用户表;(users)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-10-12
 */
@Api(tags = "用户表对象功能接口")
@RestController
@RequestMapping("/")
public class UsersController extends BaseController {

    @Autowired
    private UsersService usersService;

    @Autowired
    private RolesService rolesService;

    @Autowired
    private ResourcesService resourcesService;

    /**
     * 通过ID查询单条数据
     *
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/users/current")
    public ResponseBean queryCurrent() throws Exception {
        int userId = StpUtil.getLoginIdAsInt();
        return queryById(userId);
    }

    /**
     * 通过ID查询单条数据
     *
     * @return 实例对象
     */
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/users/{id}")
    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable Integer id) throws Exception {
        Users users = usersService.getById(id);
        if (null == users || users.getStatus() == Constants.STATUS_DELETE) {
            return ResponseBean.error("用户不存在");
        }

        users.setPassword(null);

        List<Roles> rolesList = rolesService.getByUser(users.getId());
        users.setRolesList(rolesList);

        List<Resources> resourcesList = resourcesService.getByUser(users.getId());
        users.setResourcesList(resourcesList);

        return ResponseBean.success(users);
    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("分页查询")
    @GetMapping("/users")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                             @ApiParam("姓名") @RequestParam(value = "name", required = false) String name,
                             @ApiParam("部门") @RequestParam(value = "dept", required = false) String dept,
                             @ApiParam("手机号") @RequestParam(value = "phone", required = false) String phone) throws Exception {

        IPage<Users> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<Users> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(name), "name", name);
        queryWrapper.like(!StringUtils.isEmpty(dept), "dept", dept);
        queryWrapper.like(!StringUtils.isEmpty(phone), "phone", phone);
        queryWrapper.gt("status", Constants.STATUS_DELETE);
        queryWrapper.ne("id", Constants.ROOT_ID);
        queryWrapper.orderByDesc("create_date");
        IPage<Users> result = usersService.page(pg, queryWrapper);

        return ResponseBean.success(result);
    }

    /**
     * 新增数据
     *
     * @param users 实例对象
     * @return 实例对象
     */
    @ApiOperation("新增数据")
    @PostMapping("/users")
    public ResponseBean add(@ApiParam("对象实体") @RequestBody Users users) throws Exception {
        usersService.mergeData(users);
        return ResponseBean.success(users);
    }

    /**
     * 更新数据
     *
     * @param id 实例ID
     * @return 实例对象
     */
    @ApiOperation("更新数据")
    @PutMapping("/users/{id}/status")
    public ResponseBean edit(@ApiParam("对象ID") @PathVariable Integer id,
                             @ApiParam("页码") @RequestParam(value = "status") Integer status) throws Exception {

        Users users = usersService.getById(id);
        users.setStatus(status);

        usersService.updateById(users);
        return ResponseBean.success(users);
    }

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/users/{id}")
    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable Integer id) {
        usersService.removeLogicById(id);
        return ResponseBean.success("success");
    }
}