package com.yunzhi.inte.service.impl;

import com.yunzhi.inte.common.StringUtils;
import com.yunzhi.inte.entity.UnitsFiles;
import com.yunzhi.inte.mapper.UnitsFilesMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yunzhi.inte.entity.CooperationUnits;
import com.yunzhi.inte.mapper.CooperationUnitsMapper;
import com.yunzhi.inte.service.CooperationUnitsService;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

/**
 * 保障机构;(cooperation_units)表服务实现类
 * @author : http://www.chiner.pro
 * @date : 2022-10-24
 */
@Service
public class CooperationUnitsServiceImpl extends BaseServiceImpl<CooperationUnitsMapper, CooperationUnits> implements CooperationUnitsService {

    @Autowired
    UnitsFilesMapper unitsFilesMapper;

  @Override
  @Transactional(rollbackFor = Exception.class)
  public void mergeData(CooperationUnits cooperationUnits) throws Exception {
      if (StringUtils.isEmpty(cooperationUnits.getName())) {
          throw new Exception("机构名称不能为空");
      }

      LocalDateTime now = LocalDateTime.now();

      Integer id = cooperationUnits.getId();
      if (id == null) {
          CooperationUnits origin = getExistBy("name", cooperationUnits.getName(), false, false);
          if (origin != null) {
              throw new Exception("机构名称重复");
          }

          save(cooperationUnits);
          id = cooperationUnits.getId();
      } else {
          CooperationUnits exists = getByButNot("name", cooperationUnits.getName(), "id", cooperationUnits.getId(), false);
          if (exists != null) {
              throw new Exception("机构名称重复");
          }
          updateById(cooperationUnits);
      }

      List<UnitsFiles> fileList = cooperationUnits.getFileList();
      if (null == fileList || fileList.size() == 0) {
          unitsFilesMapper.deleteByMap(new HashMap<String, Object>(){{
              put("org_id", cooperationUnits.getId());
          }});
      } else {
          List<Integer> idList = new ArrayList<>();
          for (UnitsFiles file : fileList) {
              file.setOrgId(cooperationUnits.getId());

              UnitsFiles exits = unitsFilesMapper.getByFileAddr(cooperationUnits.getId(), file.getFileAddr());
              if (null != exits) {
                  file.setId(exits.getId());
                  unitsFilesMapper.updateById(file);
              } else {
                  unitsFilesMapper.insert(file);
              }

              idList.add(file.getId());
          }

          unitsFilesMapper.deleteButNotIn(cooperationUnits.getId(), idList);
      }
  }
 }