package com.yunzhi.inte.service.impl;

import com.yunzhi.inte.common.Constants;
import com.yunzhi.inte.common.StringUtils;
import com.yunzhi.inte.entity.*;
import com.yunzhi.inte.mapper.PurchaseItemsMapper;
import com.yunzhi.inte.mapper.StoreLogMapper;
import com.yunzhi.inte.mapper.StoreMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yunzhi.inte.mapper.PurchaseMapper;
import com.yunzhi.inte.service.PurchaseService;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 采购表;(purchase)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2022-10-14
 */
@Service
public class PurchaseServiceImpl extends BaseServiceImpl<PurchaseMapper, Purchase> implements PurchaseService {

    @Autowired
    PurchaseItemsMapper purchaseItemsMapper;

    @Autowired
    StoreMapper storeMapper;

    @Autowired
    StoreLogMapper storeLogMapper;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean mergeData(Purchase purchase) throws Exception {
        if (StringUtils.isEmpty(purchase.getTitle())) {
            throw new Exception("采购计划名称不能为空");
        }

        LocalDateTime now = LocalDateTime.now();

        // 主表
        Integer purchaseId = purchase.getId();
        if (null == purchaseId) {
            Purchase origin = getExistBy("title", purchase.getTitle(), false, true);
            if (null != origin) {
                throw new Exception("采购计划名称重复");
            }

            if (null == purchase.getStatus()) {
                purchase.setStatus(Constants.STATUS_NORMAL);
            }

            purchase.setCreateDate(now);
            save(purchase);
            purchaseId = purchase.getId();
        } else {
            Purchase origin = getById(purchaseId);

            if ((null != origin.getIsCompleted() && origin.getIsCompleted())
            || (null != origin.getIsInStore() && origin.getIsInStore())) {
                throw new Exception("当前采购计划已结束, 禁止修改");
            }

            Purchase exists = getByButNot("title", purchase.getTitle(), "id", purchaseId, true);
            if (null != exists) {
                throw new Exception("采购计划名称重复");
            }

            updateById(purchase);
        }

        // 明细表
        List<String> itemNames = new ArrayList<>();
        List<PurchaseItems> itemsList = purchase.getItemsList();
        if (null == itemsList || itemsList.size() == 0) {
            // 清空明细数据
            purchaseItemsMapper.deleteByMap(new HashMap<String, Object>(){{
                put("purchase_id", purchase.getId());
            }});
        } else {
            List<Integer> idList = new ArrayList<>();
            for (PurchaseItems item : itemsList) {
                item.setPurchaseId(purchase.getId());

                if (null == item.getStoreId()) {
                    continue;
                }

                Store store = storeMapper.selectById(item.getStoreId());
                if (null == store) {
                    continue;
                }

                if (itemNames.size() < 4) {
                    itemNames.add(store.getName());
                }

                PurchaseItems exists = purchaseItemsMapper.getByStore(purchaseId, item.getStoreId());
                if (null != exists) {
                    item.setId(exists.getId());
                    purchaseItemsMapper.updateById(item);
                } else {
                    item.setCreateDate(now);
                    purchaseItemsMapper.insert(item);
                }

                idList.add(item.getId());
            }

            // 去除垃圾数据
            purchaseItemsMapper.deleteNotIn(purchase.getId(), idList);
        }

        purchase.setItems(String.join(",", itemNames));
        updateById(purchase);

        return true;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean inStore(Integer purchaseId, Users users) throws Exception {
        LocalDateTime now = LocalDateTime.now();

        Purchase purchase = getById(purchaseId);
        if (null == purchase) {
            throw new Exception("未找到采购计划");
        }

        if (null == purchase.getIsCompleted() || !purchase.getIsCompleted()) {
            throw new Exception("当前采购未完成");
        }

        if (null != purchase.getIsInStore() && purchase.getIsInStore()) {
            throw new Exception("当前采购已入库");
        }

        purchase.setIsInStore(true);
        updateById(purchase);

        // 明细
        List<PurchaseItems> purchaseItemsList = purchaseItemsMapper.selectByMap(new HashMap<String, Object>() {{
            put("purchase_id", purchaseId);
        }});

        if (null != purchaseItemsList && purchaseItemsList.size() > 0) {
            for (PurchaseItems item: purchaseItemsList) {
                Store store = storeMapper.selectById(item.getStoreId());
                if (null == store) continue;

                Double preAmount = store.getAmount() == null ? 0 : store.getAmount();
                Double amount = item.getActAmount() == null ? 0 : item.getActAmount();
                StoreLog storeLog = new StoreLog();
                storeLog.setStoreId(store.getId().toString());
                storeLog.setOptType("in");
                storeLog.setPreAmount(preAmount);
                storeLog.setAmount(amount);
                storeLog.setAftAmount(preAmount + amount);
                storeLog.setCreateUser(users.getId());
                storeLog.setCreateUserName(users.getName());
                storeLog.setCreateDate(now);

                storeLogMapper.insert(storeLog);

                store.setAmount(storeLog.getAftAmount());
                storeMapper.updateById(store);
            }
        }

        return true;
    }

    @Override
    public List<Map<String, Object>> getCostByDays(String startDate, String endDate, Long days) {
        return baseMapper.getCostByDays(startDate, endDate, days);
    }

    @Override
    public List<Map<String, Object>> getCostByMonths(String startDate, String endDate, long months) {
        return baseMapper.getCostByMonths(startDate, endDate, months);
    }
}
