package com.yunzhi.inte.service.impl;

import com.yunzhi.inte.common.Constants;
import com.yunzhi.inte.common.EncryptUtils;
import com.yunzhi.inte.common.StringUtils;
import com.yunzhi.inte.entity.*;
import com.yunzhi.inte.mapper.RolesMapper;
import com.yunzhi.inte.mapper.UserRolesMapper;
import com.yunzhi.inte.vo.LoginParm;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yunzhi.inte.mapper.UsersMapper;
import com.yunzhi.inte.service.UsersService;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 用户表;(users)表服务实现类
 *
 * @author : http://www.chiner.pro
 * @date : 2022-10-12
 */
@Service
public class UsersServiceImpl extends BaseServiceImpl<UsersMapper, Users> implements UsersService {

    @Autowired
    UserRolesMapper userRolesMapper;


    @Override
    public Users login(LoginParm loginParm) throws Exception {
        Users sysUser = baseMapper.getByLoginID(loginParm.getUserName());
        if (null == sysUser) {
            throw new Exception("用户名或者密码不正确");
        }

        boolean isRight = checkPassword(loginParm.getPassword(), sysUser.getPassword(), sysUser.getId().toString());
        if (!isRight) {
            throw new Exception("用户名或者密码不正确");
        }

        sysUser.setPassword(null);
        return sysUser;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean mergeData(Users users) throws Exception {
        if (StringUtils.isEmpty(users.getName())) {
            throw new Exception("采购计划名称不能为空");
        }

        LocalDateTime now = LocalDateTime.now();

        // 用户表
        Integer userId = users.getId();
        if (null == userId) {
            Users origin = getExistBy("name", users.getName(), false, true);
            if (null != origin) {
                throw new Exception("名称重复");
            }

            if (!StringUtils.isEmpty(users.getPhone())) {
                Users origin2 = getExistBy("phone", users.getPhone(), false, true);
                if (null != origin2) {
                    throw new Exception("手机号重复");
                }
            }

            if (null == users.getStatus()) {
                users.setStatus(Constants.STATUS_NORMAL);
            }

            users.setCreateDate(now);
            save(users);
            userId = users.getId();
        } else {
            Users origin = getByButNot("name", users.getName(), "id", userId, true);
            if (null != origin) {
                throw new Exception("名称重复");
            }

            if (!StringUtils.isEmpty(users.getPhone())) {
                Users origin2 = getByButNot("phone", users.getPhone(), "id", userId, true);
                if (null != origin2) {
                    throw new Exception("手机号重复");
                }
            }

            //
            updateById(users);
        }

        // 如果密码不为空, 说明修改了密码
        if (!StringUtils.isEmpty(users.getPassword())) {
            users.setPassword(EncryptUtils.md5(users.getPassword(), users.getId().toString()));
            updateById(users);
        }

        // 授权角色
        List<Roles> rolesList = users.getRolesList();
        if (null == rolesList || rolesList.size() == 0) {
            userRolesMapper.deleteByMap(new HashMap<String, Object>() {{
                put("user_id", users.getId());
            }});
        } else {
            List<Integer> idList = new ArrayList<>();
            for (Roles role : rolesList) {
                UserRoles item = new UserRoles();
                item.setUserId(users.getId());
                item.setRoleId(role.getId());

                UserRoles exists = userRolesMapper.getByUserAndRole(users.getId(), role.getId());
                if (null != exists) {
                    item.setId(exists.getId());
                } else {
                    userRolesMapper.insert(item);
                }

                idList.add(item.getId());
            }

            // 去除垃圾数据
            userRolesMapper.deleteNotIn(users.getId(), idList);
        }

        return true;
    }

    @Override
    public List<Map<String, Integer>> countEdu() {
        return baseMapper.countEdu();
    }

    @Override
    public List<Map<String, Integer>> countAge() {
        return baseMapper.countAge();
    }

    boolean checkPassword(String src, String targ, String salt) {
        String newPass = EncryptUtils.md5(src, salt);
        return targ.equals(newPass);
    }
}